@@ -16,30 +16,30 @@
 dgenbeta <-
     function (x, shape1, shape2, shape3, rate = 1, scale = 1/rate,
               log = FALSE)
-    .External("do_dpq", "dgenbeta", x, shape1, shape2, shape3, scale, log)
+    .External("actuar_do_dpq", "dgenbeta", x, shape1, shape2, shape3, scale, log)
 
 pgenbeta <-
     function (q, shape1, shape2, shape3, rate = 1, scale = 1/rate,
               lower.tail = TRUE, log.p = FALSE)
-    .External("do_dpq", "pgenbeta", q, shape1, shape2, shape3, scale,
+    .External("actuar_do_dpq", "pgenbeta", q, shape1, shape2, shape3, scale,
               lower.tail, log.p)
 
 qgenbeta <-
     function (p, shape1, shape2, shape3, rate = 1, scale = 1/rate,
               lower.tail = TRUE, log.p = FALSE)
-    .External("do_dpq", "qgenbeta", p, shape1, shape2, shape3, scale,
+    .External("actuar_do_dpq", "qgenbeta", p, shape1, shape2, shape3, scale,
               lower.tail, log.p)
 
 rgenbeta <-
     function (n, shape1, shape2, shape3, rate = 1, scale = 1/rate)
-    .External("do_random", "rgenbeta", n, shape1, shape2, shape3, scale)
+    .External("actuar_do_random", "rgenbeta", n, shape1, shape2, shape3, scale)
 
 mgenbeta <-
     function (order, shape1, shape2, shape3, rate = 1, scale = 1/rate)
-    .External("do_dpq", "mgenbeta", order, shape1, shape2, shape3, scale, FALSE)
+    .External("actuar_do_dpq", "mgenbeta", order, shape1, shape2, shape3, scale, FALSE)
 
 levgenbeta <-
     function (limit, shape1, shape2, shape3, rate = 1, scale = 1/rate,
               order = 1)
-    .External("do_dpq", "levgenbeta", limit, shape1, shape2, shape3, scale,
+    .External("actuar_do_dpq", "levgenbeta", limit, shape1, shape2, shape3, scale,
               order, FALSE)
