@@ -34,7 +34,13 @@ double dparalogis(double x, double shape, double scale, int give_log)
         return R_D__0;
 
     /* handle x == 0 separately */
-    if (x == 0) R_D_mode(shape > 1);
+    if (x == 0)
+    {
+	if (shape < 1) return R_PosInf;
+	if (shape > 1) return R_D__0;
+	/* else */
+	return R_D_val(1.0 / scale);
+    }
 
     tmp = shape * (log(x) - log(scale));
     logu = - log1p(exp(tmp));
@@ -104,10 +110,12 @@ double mparalogis(double order, double shape, double scale, int give_log)
         !R_FINITE(scale) ||
         !R_FINITE(order) ||
         shape <= 0.0 ||
-        scale <= 0.0 ||
-        order <= -shape ||
+        scale <= 0.0)
+	return R_NaN;
+
+    if (order <= -shape ||
         order >= shape * shape)
-        return R_NaN;
+        return R_PosInf;
 
     tmp = order / shape;
 
@@ -124,12 +132,14 @@ double levparalogis(double limit, double shape, double scale, double order,
         !R_FINITE(scale) ||
         !R_FINITE(order) ||
         shape <= 0.0 ||
-        scale <= 0.0 ||
-        order <= -shape)
+        scale <= 0.0)
         return R_NaN;
 
+    if (order <= -shape)
+	return R_PosInf;
+
     if (limit <= 0.0)
-        return 0;
+        return 0.0;
 
     tmp1 = order / shape;
     tmp2 = 1.0 + tmp1;
